/**
 * @file linslave.h
 *
 * @brief This file contains definitons for LIN bus slave functions for the USBlini
 *        firmware project.
 *
 * @author Thomas Fischl (https://www.fischl.de/contact.html)
 * @copyright (c) 2021 Thomas Fischl
 * 
 * This file is part of the USBlini firmware project and is copyrighted by the
 * authors listed above. It is free for private or educational non-commercial use
 * (for a commercial license please contact the authors). It may not be
 * redistributed without the prior written consent of the authors.
 *
 * It is provided "as is" without warranty of any kind, either express or implied,
 * including without limitation any implied warranties of condition, uninterrupted
 * use, merchantability, fitness for a particular purpose, or non-infringement. In
 * no event shall the authors be liable for any direct or indirect damages arising
 * in any way out of the use of it.
 *
 */
#ifndef LINSLAVE_H
#define	LINSLAVE_H

#define HEADERID_NONE 0xff
#define SLAVETABLE_DATA_SIZE 9
#define SLAVETABLE_SIZE 16


void linslave_init(void);
void linslave_triggerIDProcessing(uint8_t pid);
void linslave_process(void);
void linslave_setTableItem(uint8_t tableid, uint8_t id, uint8_t * data, uint8_t length, uint8_t checksum_mode, uint16_t reloadvalue, uint16_t resetmask);
void linslave_setReloadvalue(uint8_t tableid, uint16_t reloadvalue);
void linslave_setResetmask(uint8_t tableid, uint16_t resetmask);

#endif	/* LINSLAVE_H */

