/**
 * @file usb.h
 *
 * @brief This file contains definitons for the usb stack functions for the USBlini
 *        firmware project.
 *
 * @author Thomas Fischl (https://www.fischl.de/contact.html)
 * @copyright (c) 2021 Thomas Fischl
 * 
 * This file is part of the USBlini firmware project and is copyrighted by the
 * authors listed above. It is free for private or educational non-commercial use
 * (for a commercial license please contact the authors). It may not be
 * redistributed without the prior written consent of the authors.
 *
 * It is provided "as is" without warranty of any kind, either express or implied,
 * including without limitation any implied warranties of condition, uninterrupted
 * use, merchantability, fitness for a particular purpose, or non-infringement. In
 * no event shall the authors be liable for any direct or indirect damages arising
 * in any way out of the use of it.
 *
 */
#ifndef _USB_CDC_
#define _USB_CDC_

void usb_init(void);
void usb_shutdown(void);
void usb_process(void);
volatile unsigned char * usb_ep1_getBuffer(void);
void usb_ep1_put(unsigned char * data, unsigned char len);
void usb_ep2_put(unsigned char ch);

extern unsigned char usb_vendor_setup(unsigned char * data, unsigned char * response);
extern unsigned char usb_vendor_out(unsigned char * data, unsigned char length);
extern unsigned char usb_vendor_in(unsigned char * data, unsigned char length);




#define USB_PID_SETUP 0xD

/* Setup Requests */
#define REQUEST_GET_STATUS 0x00
#define REQUEST_CLEAR_FEATURE 0x01
#define REQUEST_SET_FEATURE 0x03
#define REQUEST_SET_ADDRESS 0x05
#define REQUEST_GET_DESCRIPTOR 0x06
#define REQUEST_GET_CONFIGURATION 0x08
#define REQUEST_SET_CONFIGURATION 0x09
#define REQUEST_GET_INTERFACE 0x0A
#define REQUEST_SET_INTERFACE 0x11
#define REQUEST_SYNCH_FRAME 0x12

/* USB request type values */
#define USBRQ_TYPE_MASK         0x60
#define USBRQ_TYPE_STANDARD     (0<<5)
#define USBRQ_TYPE_CLASS        (1<<5)
#define USBRQ_TYPE_VENDOR       (2<<5)

#define USBRQ_RECIPIENT_MASK    0x1f
#define USBRQ_RECIPIENT_DEVICE  0x00
#define USBRQ_RECIPIENT_INTERFACE 0x01
#define USBRQ_RECIPIENT_ENDPOINT 0x02
#define USBRQ_RECIPIENT_OTHER   0x03

/* USB status flags */
#define USTAT_EP0_OUT 0x00
#define USTAT_EP0_IN 0x04
#define USTAT_EP1_IN 0x0C

/* Endpoint definitions */
#define EP_MAX 2
#define EP_BUFFERSIZE 8
#define EP_BULK_BUFFERSIZE 64


#define TXBUFFER_SIZE 64 //128

typedef struct
{
    unsigned char stat;
    unsigned char cnt;
    unsigned char adrl;
    unsigned char adrh;
} BDT;

#define EPBD_NROF 10
#define EPBD_EP0_OUT 0
#define EPBD_EP0_IN 1
#define EPBD_EP1_IN_EVEN 4
#define EPBD_EP1_IN_ODD 5
#define EPBD_EP2_IN_EVEN 8
#define EPBD_EP2_IN_ODD 9


#define USB_DEV_DESC_SERIALNUMBER_OFFSET 16
#define USB_STRING_SERIALNUMBER_INDEX 3
#define USB_STRING_SERIALNUMBER_SIZE 18
extern const unsigned char usb_string_serial[] __at(0x0700);

#endif

